@@ -302,7 +302,7 @@ void F77_NAME(catmax)(double *parentDen, double *tclasscat,
     int j, k, n, icat[32], nsplit;
     double leftNum, leftDen, rightNum, decGini, *leftCatClassCount;
 
-    leftCatClassCount = (double *) Calloc(*nclass, double);
+    leftCatClassCount = (double *) R_Calloc(*nclass, double);
     *nhit = 0;
     nsplit = *lcat > *ncmax ?
         *ncsplit : (int) pow(2.0, (double) *lcat - 1) - 1;
@@ -347,7 +347,7 @@ void F77_NAME(catmax)(double *parentDen, double *tclasscat,
             *ncatsp = *lcat > *ncmax ? pack((unsigned int) *lcat, icat) : n + 1;
         }
     }
-    Free(leftCatClassCount);
+    R_Free(leftCatClassCount);
 }
 
 
@@ -427,7 +427,7 @@ void predictClassTree(double *x, int n, int mdim, int *treemap,
 
     /* decode the categorical splits */
     if (maxcat > 1) {
-        cbestsplit = (int *) Calloc(maxcat * treeSize, int);
+        cbestsplit = (int *) R_Calloc(maxcat * treeSize, int);
         zeroInt(cbestsplit, maxcat * treeSize);
         for (i = 0; i < treeSize; ++i) {
             if (nodestatus[i] != NODE_TERMINAL) {
@@ -459,5 +459,5 @@ void predictClassTree(double *x, int n, int mdim, int *treemap,
 		jts[i] = nodeclass[k];
 		nodex[i] = k + 1;
     }
-    if (maxcat > 1) Free(cbestsplit);
+    if (maxcat > 1) R_Free(cbestsplit);
 }
